@@ -6,10 +6,11 @@ Type annotations for route53-recovery-cluster service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_route53_recovery_cluster import Route53RecoveryClusterClient
+    from boto3.session import Session
+    from mypy_boto3_route53_recovery_cluster.client import Route53RecoveryClusterClient
 
-    client: Route53RecoveryClusterClient = boto3.client("route53-recovery-cluster")
+    session = Session()
+    client: Route53RecoveryClusterClient = session.client("route53-recovery-cluster")
     ```
 """
 from typing import Any, Dict, Mapping, Sequence, Type
@@ -43,7 +44,7 @@ class Exceptions:
 
 class Route53RecoveryClusterClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html)
     """
 
@@ -53,13 +54,16 @@ class Route53RecoveryClusterClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         Route53RecoveryClusterClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#can_paginate)
         """
 
@@ -73,7 +77,7 @@ class Route53RecoveryClusterClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#generate_presigned_url)
         """
 
@@ -83,7 +87,7 @@ class Route53RecoveryClusterClient(BaseClient):
         """
         Get the state for a routing control.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.get_routing_control_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.get_routing_control_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#get_routing_control_state)
         """
 
@@ -93,7 +97,7 @@ class Route53RecoveryClusterClient(BaseClient):
         """
         Set the state of the routing control to reroute traffic.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.update_routing_control_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.update_routing_control_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#update_routing_control_state)
         """
 
@@ -103,6 +107,6 @@ class Route53RecoveryClusterClient(BaseClient):
         """
         Set multiple routing control states.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.update_routing_control_states)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.update_routing_control_states)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#update_routing_control_states)
         """
